/*
 * Automatically generated by Configure - don't edit
 */
# 

/* 
# Protocol Families.
 * Protocol Families.
# 
 * 
 */
#define HAVE_AFUNIX 1
#define HAVE_AFINET 1
#define HAVE_AFAX25 1
#define HAVE_AFIPX 0
# 

/* 
# Device Hardware types.
 * Device Hardware types.
# 
 * 
 */
#define HAVE_HWETHER 1
#define HAVE_HWSLIP 1
#define HAVE_HWAX25 1
